#[non_exhaustive]pub enum DataTransferError {
TypeNotFound,
}Expand description
An error which can occur while fetching data from a DataTransfer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TypeNotFound
The type was not listed in the set of available MIME types.