pub struct LogMessageLocation<'a> {
pub path: &'a str,
pub line: usize,
pub column: usize,
}Expand description
Location information attached to a log message.
Fields
path: &'a strThe file path of the source that emitted the log message
line: usizethe line number of the call that emitted the log message (1-based)
column: usizeThe column of the call that emitted the log message (1-based)