pub struct CachedPath { /* private fields */ }Available on crate features
ffi or std only.Expand description
A struct that provides a path as a string as well as the last modification time of the file it points to.