#[repr(C)]pub struct PathLineTo {
pub x: f32,
pub y: f32,
}Available on crate feature
path only.Expand description
PathLineTo describes the event of moving the cursor on the path to the specified location along a straight line.
Fields
x: f32The x coordinate where the line should go to.
y: f32The y coordinate where the line should go to.
Implementations
Sourceimpl PathLineTo
impl PathLineTo
Sourcepub const FIELD_OFFSETS: PathLineToFieldsOffsets = PathLineToFieldsOffsets
pub const FIELD_OFFSETS: PathLineToFieldsOffsets = PathLineToFieldsOffsets
Return a zero-sized helper whose methods return field offsets.