#[repr(C)]pub struct PathMoveTo {
pub x: f32,
pub y: f32,
}Available on crate feature
path only.Expand description
PathMoveTo describes the event of setting the cursor on the path to use as starting
point for sub-sequent events, such as LineTo. Moving the cursor also implicitly closes
sub-paths and therefore beings a new sub-path.
Fields
x: f32The x coordinate where the current position should be.
y: f32The y coordinate where the current position should be.
Implementations
Sourceimpl PathMoveTo
impl PathMoveTo
Sourcepub const FIELD_OFFSETS: PathMoveToFieldsOffsets = PathMoveToFieldsOffsets
pub const FIELD_OFFSETS: PathMoveToFieldsOffsets = PathMoveToFieldsOffsets
Return a zero-sized helper whose methods return field offsets.