pub enum BackendDragEvent {
Move {
event: DropEvent,
allowed: AllowedDragActions,
},
Drop {
event: DropEvent,
allowed: AllowedDragActions,
},
Leave,
}Expand description
The drag and drop events a backend can deliver, through WindowInner::process_drag_event.
Variants
Move
A drag is hovering over the window.
Drop
A drag was released over the window.
Leave
A drag left the window, or was cancelled while hovering over it.