#[repr(u8)]pub enum KeyEventResult {
EventAccepted = 0,
EventIgnored = 1,
}Expand description
Represents how an item’s key_event handler dealt with a key event. An accepted event results in no further event propagation.
Variants
EventAccepted = 0
The event was handled.
EventIgnored = 1
The event was not handled and should be sent to other items.