#[repr(u8)]pub enum TouchPhase {
Started = 0,
Moved = 1,
Ended = 2,
Cancelled = 3,
}Expand description
Phase of a touch, gesture event or wheel event. A touchpad is recognized as wheel event and therefore we need to find out when the touch event starts and ends
Variants
Started = 0
The gesture began (e.g., first finger touched or platform gesture started).
Moved = 1
The gesture is ongoing (e.g., fingers moved or platform gesture updated).
Ended = 2
The gesture completed normally.
Cancelled = 3
The gesture was cancelled (e.g., interrupted by the system) or the mouse wheel was used