InternalKeyEvent

Struct InternalKeyEvent 

pub struct InternalKeyEvent {
    pub key_event: KeyEvent,
    pub event_type: KeyEventType,
    pub replacement_range: Option<Range<i32>>,
    pub preedit_text: SharedString,
    pub preedit_selection: Option<Range<i32>>,
    pub cursor_position: Option<i32>,
    pub anchor_position: Option<i32>,
}
This struct is used to pass key events to the runtime.

Fields

key_event: KeyEvent

That’s the public type with only public fields

event_type: KeyEventType

Indicates whether the key was pressed or released

replacement_range: Option<Range<i32>>

If the event type is KeyEventType::UpdateComposition or KeyEventType::CommitComposition, then this field specifies what part of the current text to replace. Relative to the offset of the pre-edit text within the text input element’s text.

preedit_text: SharedString

If the event type is KeyEventType::UpdateComposition, this is the new pre-edit text

preedit_selection: Option<Range<i32>>

The selection within the preedit_text

cursor_position: Option<i32>

The new cursor position, when None, the cursor is put after the text that was just inserted

anchor_position: Option<i32>

The anchor position, when None, the cursor is put after the text that was just inserted

Implementations

Source

impl InternalKeyEvent

pub fn shortcut(&self) -> Option<StandardShortcut>

If a shortcut was pressed, this function returns Some(StandardShortcut). Otherwise it returns None.

pub fn text_shortcut(&self) -> Option<TextShortcut>

If a shortcut concerning text editing was pressed, this function returns Some(TextShortcut). Otherwise it returns None.