pub struct MouseInputState { /* private fields */ }Expand description
The state which a window should hold for the mouse input
Implementations
Sourceimpl MouseInputState
impl MouseInputState
Sourcepub fn top_item_including_delayed(&self) -> Option<ItemRc>
pub fn top_item_including_delayed(&self) -> Option<ItemRc>
Returns the item in the top of the stack, if there is a delayed event, this would be the top of the delayed stack
Sourcepub fn has_delayed_event(&self) -> bool
pub fn has_delayed_event(&self) -> bool
Returns true if there is a pending delayed event (e.g. from a Flickable)
Sourcepub fn drop_target_action(&self) -> Option<DragAction>
pub fn drop_target_action(&self) -> Option<DragAction>
The action negotiated with the DropArea that accepted the most recent
DragMove/Drop, or None if none accepted.