#[non_exhaustive]#[repr(u32)]pub enum CrossAxisAlignment {
Auto = 0,
Stretch = 1,
Start = 2,
End = 3,
Center = 4,
}Expand description
Controls the alignment of items along the cross axis of a layout.
Used as the cross-axis-alignment property of HorizontalLayout, VerticalLayout,
and FlexboxLayout, and as the cross-axis-self-alignment property of their
children, which overrides the container’s alignment for a single item.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auto = 0
The default: for cross-axis-self-alignment, use the container’s
cross-axis-alignment value. For an unset cross-axis-alignment it is
equivalent to stretch; it is an error to set it explicitly there.
Stretch = 1
Items are stretched to fill the cross axis.
Start = 2
Items are placed at the start of the cross axis.
End = 3
Items are placed at the end of the cross axis.
Center = 4
Items are centered along the cross axis.