#[non_exhaustive]#[repr(u32)]pub enum DialogButtonRole {
None = 0,
Accept = 1,
Reject = 2,
Apply = 3,
Reset = 4,
Help = 5,
Action = 6,
}Expand description
This enum represents the value of the dialog-button-role property which can be added to
any element within a Dialog to put that item in the button row, and its exact position
depends on the role and the platform.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None = 0
This isn’t a button meant to go into the bottom row
Accept = 1
This is the role of the main button to click to accept the dialog. e.g. “Ok” or “Yes”
Reject = 2
This is the role of the main button to click to reject the dialog. e.g. “Cancel” or “No”
Apply = 3
This is the role of the “Apply” button
Reset = 4
This is the role of the “Reset” button
Help = 5
This is the role of the “Help” button
Action = 6
This is the role of any other button that performs another action.