#[non_exhaustive]#[repr(u32)]pub enum FillRule {
Nonzero = 0,
Evenodd = 1,
}Expand description
This enum describes the different ways of deciding what the inside of a shape described by a path shall be.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.