#[non_exhaustive]#[repr(u32)]pub enum FlexboxLayoutAlignContent {
Stretch = 0,
Start = 1,
End = 2,
Center = 3,
SpaceBetween = 4,
SpaceAround = 5,
SpaceEvenly = 6,
}Expand description
Controls the distribution of flex lines along the cross axis in a flex container.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Stretch = 0
Lines are stretched to fill the container along the cross axis.
Start = 1
Lines are placed at the start of the cross axis.
End = 2
Lines are placed at the end of the cross axis.
Center = 3
Lines are centered along the cross axis.
SpaceBetween = 4
Equal gaps between lines, no gap at the edges.
SpaceAround = 5
Equal gaps around each line (half-size at edges).
SpaceEvenly = 6
Equal gaps between lines and at the edges.