#[non_exhaustive]#[repr(u32)]pub enum FlexboxLayoutAlignSelf {
Auto = 0,
Stretch = 1,
Start = 2,
End = 3,
Center = 4,
}Expand description
Overrides the container’s cross-axis-alignment for a specific flex item.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auto = 0
Use the container’s cross-axis-alignment value (default).
Stretch = 1
The item is stretched to fill the line along the cross axis.
Start = 2
The item is placed at the start of the cross axis.
End = 3
The item is placed at the end of the cross axis.
Center = 4
The item is centered along the cross axis.