#[non_exhaustive]#[repr(u32)]pub enum LineJoin {
Miter = 0,
Round = 1,
Bevel = 2,
}Expand description
This enum describes the appearance of the joins between segments of stroked paths.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Miter = 0
The stroke joins with a sharp corner or a clipped corner, depending on the miter limit.
Round = 1
The stroke joins with a smooth, rounded corner.
Bevel = 2
The stroke joins with a beveled (flattened) corner.