pub struct Path {Show 16 fields
pub elements: Property<PathData>,
pub fill: Property<Brush>,
pub fill_rule: Property<FillRule>,
pub stroke: Property<Brush>,
pub stroke_width: Property<LogicalLength>,
pub stroke_line_cap: Property<LineCap>,
pub stroke_line_join: Property<LineJoin>,
pub stroke_miter_limit: Property<f32>,
pub viewbox_x: Property<f32>,
pub viewbox_y: Property<f32>,
pub viewbox_width: Property<f32>,
pub viewbox_height: Property<f32>,
pub fit: Property<ImageFit>,
pub clip: Property<bool>,
pub anti_alias: Property<bool>,
pub cached_rendering_data: CachedRenderingData,
/* private fields */
}Available on crate feature
path only.Expand description
The implementation of the Path element
Fields
elements: Property<PathData>fill: Property<Brush>fill_rule: Property<FillRule>stroke: Property<Brush>stroke_width: Property<LogicalLength>stroke_line_cap: Property<LineCap>stroke_line_join: Property<LineJoin>stroke_miter_limit: Property<f32>viewbox_x: Property<f32>viewbox_y: Property<f32>viewbox_width: Property<f32>viewbox_height: Property<f32>fit: Property<ImageFit>clip: Property<bool>anti_alias: Property<bool>cached_rendering_data: CachedRenderingDataImplementations
Sourceimpl Path
impl Path
Sourcepub const FIELD_OFFSETS: PathFieldsOffsets = PathFieldsOffsets
pub const FIELD_OFFSETS: PathFieldsOffsets = PathFieldsOffsets
Return a zero-sized helper whose methods return field offsets.
Sourceimpl Path
impl Path
pub fn elements(self: Pin<&Self>) -> PathData
pub fn fill(self: Pin<&Self>) -> Brush
pub fn fill_rule(self: Pin<&Self>) -> FillRule
pub fn stroke(self: Pin<&Self>) -> Brush
pub fn stroke_width(self: Pin<&Self>) -> LogicalLength
pub fn stroke_line_cap(self: Pin<&Self>) -> LineCap
pub fn stroke_line_join(self: Pin<&Self>) -> LineJoin
pub fn stroke_miter_limit(self: Pin<&Self>) -> f32
pub fn viewbox_x(self: Pin<&Self>) -> f32
pub fn viewbox_y(self: Pin<&Self>) -> f32
pub fn viewbox_width(self: Pin<&Self>) -> f32
pub fn viewbox_height(self: Pin<&Self>) -> f32
pub fn fit(self: Pin<&Self>) -> ImageFit
pub fn clip(self: Pin<&Self>) -> bool
pub fn anti_alias(self: Pin<&Self>) -> bool
Sourceimpl Path
impl Path
Sourcepub fn fitted_path_events(
self: Pin<&Self>,
self_rc: &ItemRc,
) -> Option<(LogicalVector, PathDataIterator)>
pub fn fitted_path_events( self: Pin<&Self>, self_rc: &ItemRc, ) -> Option<(LogicalVector, PathDataIterator)>
Returns an iterator of the events of the path and an offset, so that the shape fits into the width/height of the path while respecting the stroke width.
pub fn point_at( self: Pin<&Self>, self_rc: &ItemRc, t: f32, ) -> Point2D<f32, LogicalPx>
pub fn angle_at(self: Pin<&Self>, self_rc: &ItemRc, t: f32) -> f32