pub struct TextInput {Show 33 fields
pub text: Property<SharedString>,
pub font_family: Property<SharedString>,
pub font_size: Property<LogicalLength>,
pub font_weight: Property<i32>,
pub font_italic: Property<bool>,
pub color: Property<Brush>,
pub selection_foreground_color: Property<Color>,
pub selection_background_color: Property<Color>,
pub horizontal_alignment: Property<TextHorizontalAlignment>,
pub vertical_alignment: Property<TextVerticalAlignment>,
pub wrap: Property<TextWrap>,
pub input_type: Property<InputType>,
pub input_method_hints: Property<InputMethodHints>,
pub letter_spacing: Property<LogicalLength>,
pub line_height_factor: Property<f32>,
pub width: Property<LogicalLength>,
pub height: Property<LogicalLength>,
pub cursor_position_byte_offset: Property<i32>,
pub anchor_position_byte_offset: Property<i32>,
pub text_cursor_width: Property<LogicalLength>,
pub page_height: Property<LogicalLength>,
pub cursor_visible: Property<bool>,
pub has_focus: Property<bool>,
pub enabled: Property<bool>,
pub accepted: Callback<VoidArg>,
pub cursor_position_changed: Callback<(LogicalPosition,)>,
pub edited: Callback<VoidArg>,
pub key_pressed: Callback<KeyEventArg, EventResult>,
pub key_released: Callback<KeyEventArg, EventResult>,
pub single_line: Property<bool>,
pub read_only: Property<bool>,
pub preedit_text: Property<SharedString>,
pub cached_rendering_data: CachedRenderingData,
/* private fields */
}Expand description
The implementation of the TextInput element
Fields
text: Property<SharedString>font_family: Property<SharedString>font_size: Property<LogicalLength>font_weight: Property<i32>font_italic: Property<bool>color: Property<Brush>selection_foreground_color: Property<Color>selection_background_color: Property<Color>horizontal_alignment: Property<TextHorizontalAlignment>vertical_alignment: Property<TextVerticalAlignment>wrap: Property<TextWrap>input_type: Property<InputType>input_method_hints: Property<InputMethodHints>letter_spacing: Property<LogicalLength>line_height_factor: Property<f32>width: Property<LogicalLength>height: Property<LogicalLength>cursor_position_byte_offset: Property<i32>anchor_position_byte_offset: Property<i32>text_cursor_width: Property<LogicalLength>page_height: Property<LogicalLength>cursor_visible: Property<bool>has_focus: Property<bool>enabled: Property<bool>accepted: Callback<VoidArg>cursor_position_changed: Callback<(LogicalPosition,)>edited: Callback<VoidArg>key_pressed: Callback<KeyEventArg, EventResult>key_released: Callback<KeyEventArg, EventResult>single_line: Property<bool>read_only: Property<bool>preedit_text: Property<SharedString>cached_rendering_data: CachedRenderingDataImplementations
Sourceimpl TextInput
impl TextInput
Sourcepub const FIELD_OFFSETS: TextInputFieldsOffsets = TextInputFieldsOffsets
pub const FIELD_OFFSETS: TextInputFieldsOffsets = TextInputFieldsOffsets
Return a zero-sized helper whose methods return field offsets.
Sourceimpl TextInput
impl TextInput
pub fn text(self: Pin<&Self>) -> SharedString
pub fn font_family(self: Pin<&Self>) -> SharedString
pub fn font_size(self: Pin<&Self>) -> LogicalLength
pub fn font_weight(self: Pin<&Self>) -> i32
pub fn font_italic(self: Pin<&Self>) -> bool
pub fn color(self: Pin<&Self>) -> Brush
pub fn selection_foreground_color(self: Pin<&Self>) -> Color
pub fn selection_background_color(self: Pin<&Self>) -> Color
pub fn horizontal_alignment(self: Pin<&Self>) -> TextHorizontalAlignment
pub fn vertical_alignment(self: Pin<&Self>) -> TextVerticalAlignment
pub fn wrap(self: Pin<&Self>) -> TextWrap
pub fn input_type(self: Pin<&Self>) -> InputType
pub fn input_method_hints(self: Pin<&Self>) -> InputMethodHints
pub fn letter_spacing(self: Pin<&Self>) -> LogicalLength
pub fn line_height_factor(self: Pin<&Self>) -> f32
pub fn width(self: Pin<&Self>) -> LogicalLength
pub fn height(self: Pin<&Self>) -> LogicalLength
pub fn cursor_position_byte_offset(self: Pin<&Self>) -> i32
pub fn anchor_position_byte_offset(self: Pin<&Self>) -> i32
pub fn text_cursor_width(self: Pin<&Self>) -> LogicalLength
pub fn page_height(self: Pin<&Self>) -> LogicalLength
pub fn cursor_visible(self: Pin<&Self>) -> bool
pub fn has_focus(self: Pin<&Self>) -> bool
pub fn enabled(self: Pin<&Self>) -> bool
pub fn single_line(self: Pin<&Self>) -> bool
pub fn read_only(self: Pin<&Self>) -> bool
pub fn preedit_text(self: Pin<&Self>) -> SharedString
Sourceimpl TextInput
impl TextInput
Sourcepub fn set_cursor_position(
self: Pin<&Self>,
new_position: i32,
reset_preferred_x_pos: bool,
trigger_callbacks: TextChangeNotify,
window_adapter: &Rc<dyn WindowAdapter>,
self_rc: &ItemRc,
)
pub fn set_cursor_position( self: Pin<&Self>, new_position: i32, reset_preferred_x_pos: bool, trigger_callbacks: TextChangeNotify, window_adapter: &Rc<dyn WindowAdapter>, self_rc: &ItemRc, )
Places the cursor at a text position (next-character affinity at a soft line break). Use
Self::set_cursor_position_with_affinity for a position that came from a visual location.
pub fn set_cursor_position_with_affinity( self: Pin<&Self>, new_position: i32, affinity: TextCursorAffinity, reset_preferred_x_pos: bool, trigger_callbacks: TextChangeNotify, window_adapter: &Rc<dyn WindowAdapter>, self_rc: &ItemRc, )
pub fn delete_selection( self: Pin<&Self>, window_adapter: &Rc<dyn WindowAdapter>, self_rc: &ItemRc, trigger_callbacks: TextChangeNotify, )
pub fn anchor_position(self: Pin<&Self>, text: &str) -> usize
Sourcepub fn is_password(self: Pin<&Self>) -> bool
pub fn is_password(self: Pin<&Self>) -> bool
Whether this input masks what is typed into it.
pub fn cursor_position(self: Pin<&Self>, text: &str) -> usize
Sourcepub fn cursor_position_affinity(self: Pin<&Self>) -> TextCursorAffinity
pub fn cursor_position_affinity(self: Pin<&Self>) -> TextCursorAffinity
Which of the two visual positions the cursor byte offset means, for an offset that sits at a soft line break.
pub fn selection_anchor_and_cursor(self: Pin<&Self>) -> (usize, usize)
pub fn has_selection(self: Pin<&Self>) -> bool
pub fn cut( self: Pin<&Self>, window_adapter: &Rc<dyn WindowAdapter>, self_rc: &ItemRc, )
pub fn set_selection_offsets( self: Pin<&Self>, window_adapter: &Rc<dyn WindowAdapter>, self_rc: &ItemRc, anchor: i32, focus: i32, )
pub fn select_all( self: Pin<&Self>, window_adapter: &Rc<dyn WindowAdapter>, self_rc: &ItemRc, )
pub fn clear_selection(self: Pin<&Self>, _: &Rc<dyn WindowAdapter>, _: &ItemRc)
pub fn select_word( self: Pin<&Self>, window_adapter: &Rc<dyn WindowAdapter>, self_rc: &ItemRc, )
pub fn copy(self: Pin<&Self>, w: &Rc<dyn WindowAdapter>, _: &ItemRc)
pub fn paste( self: Pin<&Self>, window_adapter: &Rc<dyn WindowAdapter>, self_rc: &ItemRc, )
Sourcepub fn visual_representation(self: Pin<&Self>) -> TextInputVisualRepresentation
pub fn visual_representation(self: Pin<&Self>) -> TextInputVisualRepresentation
Returns a TextInputVisualRepresentation struct that contains all the fields necessary for rendering the text input,
after making adjustments such as applying a substitution of characters for password input fields, or making sure
that the selection start is always less or equal than the selection end.
pub fn byte_offset_for_position( self: Pin<&Self>, pos: LogicalPoint, window_adapter: &Rc<dyn WindowAdapter>, self_rc: &ItemRc, ) -> (usize, TextCursorAffinity)
pub fn undo( self: Pin<&Self>, window_adapter: &Rc<dyn WindowAdapter>, self_rc: &ItemRc, )
pub fn redo( self: Pin<&Self>, window_adapter: &Rc<dyn WindowAdapter>, self_rc: &ItemRc, )
pub fn font_metrics( self: Pin<&Self>, window_adapter: &Rc<dyn WindowAdapter>, self_rc: &ItemRc, ) -> FontMetrics