macro_rules! debug_log {
($($t:tt)*) => { ... };
}Expand description
This macro allows producing debug output that will appear on stderr in regular builds and in the console log for wasm builds.
macro_rules! debug_log {
($($t:tt)*) => { ... };
}This macro allows producing debug output that will appear on stderr in regular builds and in the console log for wasm builds.