shared_string_replace_all

Function shared_string_replace_all 

pub fn shared_string_replace_all(
    s: &SharedString,
    from: &str,
    to: &str,
) -> SharedString
Replaces all matches of from with to in s and returns the result as a new SharedString.