pub enum PopupWindowLocation {
TopLevel(Rc<dyn WindowAdapter>),
ChildWindow(LogicalPoint),
}Expand description
This enum describes the different ways a popup can be rendered by the back-end.
Variants
TopLevel(Rc<dyn WindowAdapter>)
The popup is rendered in its own top-level window that is know to the windowing system.
ChildWindow(LogicalPoint)
The popup is rendered as an embedded child window at the given position.