pub struct PopupWindow {
pub popup_id: NonZeroU32,
pub location: PopupWindowLocation,
pub component: ItemTreeRc,
pub close_policy: PopupClosePolicy,
pub parent_item: ItemWeak,
pub window_kind: WindowKind,
/* private fields */
}Expand description
This structure defines a graphical element that is designed to pop up from the surrounding UI content, for example to show a context menu.
Fields
popup_id: NonZeroU32The ID of the associated popup.
location: PopupWindowLocationThe location defines where the pop up is rendered.
component: ItemTreeRcThe component that is responsible for providing the popup content.
close_policy: PopupClosePolicyDefines the close behavior of the popup.
parent_item: ItemWeakThe item from where the Popup was invoked from
window_kind: WindowKindOverlay tooltip: no focus steal, unclamped placement, skipped in main mouse routing. Context / popup menu: participates in menu-chain hit testing and cascading close.