MouseEvent

Enum MouseEvent 

#[repr(C)]
pub enum MouseEvent { Pressed { position: LogicalPoint, button: PointerEventButton, click_count: u8, is_touch: bool, }, Released { position: LogicalPoint, button: PointerEventButton, click_count: u8, is_touch: bool, }, Moved { position: LogicalPoint, is_touch: bool, }, Wheel { position: LogicalPoint, delta_x: Coord, delta_y: Coord, phase: TouchPhase, }, DragMove(DropEvent), Drop(DropEvent), PinchGesture { position: LogicalPoint, delta: f32, phase: TouchPhase, }, RotationGesture { position: LogicalPoint, delta: f32, phase: TouchPhase, }, Exit, }
A mouse or touch event

The only difference with crate::platform::WindowEvent is that it uses untyped Point TODO: merge with platform::WindowEvent

Variants



Pressed

The mouse or finger was pressed

Fields

position: LogicalPoint

The position of the pointer when the event happened.

button: PointerEventButton

The button that was pressed.

click_count: u8

The current click count reported for this press.

is_touch: bool

Whether the event originated from touch input.



Released

The mouse or finger was released

Fields

position: LogicalPoint

The position of the pointer when the event happened.

button: PointerEventButton

The button that was released.

click_count: u8

The current click count reported for this release.

is_touch: bool

Whether the event originated from touch input.



Moved

The position of the pointer has changed

Fields

position: LogicalPoint

The new position of the pointer.

is_touch: bool

Whether the event originated from touch input.



Wheel

Wheel was operated.

Fields

position: LogicalPoint

The position of the pointer when the event happened.

delta_x: Coord

The horizontal scroll delta in logical pixels.

delta_y: Coord

The vertical scroll delta in logical pixels.

phase: TouchPhase

The gesture phase reported for the wheel event.



DragMove(DropEvent)

The mouse is being dragged over this item. InputEventResult::EventIgnored means that the item does not handle the drag operation and InputEventResult::EventAccepted means that the item can accept it.



Drop(DropEvent)

The mouse is released while dragging over this item.



PinchGesture

A platform-recognized pinch gesture (macOS/iOS trackpad, Qt).

Fields

position: LogicalPoint

The focal position of the gesture.

delta: f32

The incremental scale delta for this gesture update.

phase: TouchPhase

The gesture phase reported by the platform.



RotationGesture

A platform-recognized rotation gesture (macOS/iOS trackpad, Qt).

Fields

position: LogicalPoint

The focal position of the gesture.

delta: f32

The incremental rotation in degrees, where positive means clockwise.

phase: TouchPhase

The gesture phase reported by the platform.



Exit

The mouse exited the item or component

Implementations

Source

impl MouseEvent

pub fn is_touch(&self) -> Option<bool>

The flag for when event generated from touch

pub fn position(&self) -> Option<LogicalPoint>

The position of the cursor for this event, if any

pub fn translate(&mut self, vec: LogicalVector)

Translate the position by the given value

pub fn transform(&mut self, transform: ItemTransform)

Transform the position by the given item transform.