#[repr(C)]pub struct KeysInner {
pub key: SharedString,
pub modifiers: KeyboardModifiers,
pub ignore_shift: bool,
pub ignore_alt: bool,
}Expand description
Internal representation of the Keys type.
This is semver exempt and is only used to set up the native menu in the backends.
Fields
key: SharedStringThe key used to trigger the shortcut
Note: This is currently converted to lowercase when the shortcut is created!
modifiers: KeyboardModifiersKeyboardModifiers that need to be pressed for the shortcut to fire
ignore_shift: boolWhether to ignore shift state when matching the shortcut
ignore_alt: boolWhether to ignore alt state when matching the shortcut
Implementations