pub trait RenderString: HasFont {
// Required method
fn text(self: Pin<&Self>) -> PlainOrStyledText;
}Expand description
Trait for an item that represents an string towards the renderer
pub trait RenderString: HasFont {
// Required method
fn text(self: Pin<&Self>) -> PlainOrStyledText;
}Trait for an item that represents an string towards the renderer