#[non_exhaustive]#[repr(u32)]pub enum CrossAxisAlignment {
Stretch = 0,
Start = 1,
End = 2,
Center = 3,
}Expand description
Controls the alignment of individual items along the cross axis of a layout.
Used as the cross-axis-alignment property of HorizontalLayout, VerticalLayout,
and FlexboxLayout.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Stretch = 0
Items are stretched to fill the cross axis.
Start = 1
Items are placed at the start of the cross axis.
End = 2
Items are placed at the end of the cross axis.
Center = 3
Items are centered along the cross axis.