#[non_exhaustive]#[repr(C)]pub struct InputMethodHints {
pub capitalization: CapitalizationMode,
pub auto_correct: bool,
pub auto_complete: bool,
}Expand description
This structure holds the hints that a TextInput gives to the platform’s input method
(e.g. a soft keyboard) about the expected input.
The input method may take these hints into account, but might also ignore them.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.capitalization: CapitalizationModeThe auto-capitalization behavior that the input method should apply.
Defaults to CapitalizationMode::Sentences.
auto_correct: boolHint that the input method may automatically correct spelling mistakes as the user types.
Defaults to true.
auto_complete: boolHint that the input method may offer auto-completion suggestions for the entered text.
Defaults to true.