#[repr(C)]pub struct KeyEvent {
pub text: SharedString,
pub modifiers: KeyboardModifiers,
pub repeat: bool,
}Expand description
This structure is generated and passed to the key press and release callbacks of the FocusScope element.
Fields
text: SharedStringThe unicode representation of the key pressed.
modifiers: KeyboardModifiersThe keyboard modifiers active at the time of the key press event.
repeat: boolThis field is set to true for key press events that are repeated, i.e. the key is held down. It’s always false for key release events.