#[repr(C)]pub struct ScaleRotateGestureHandler {
pub enabled: Property<bool>,
pub active: Property<bool>,
pub scale: Property<f32>,
pub rotation: Property<f32>,
pub center: Property<LogicalPosition>,
pub started: Callback<VoidArg>,
pub updated: Callback<VoidArg>,
pub ended: Callback<VoidArg>,
pub cancelled: Callback<VoidArg>,
pub cached_rendering_data: CachedRenderingData,
}Expand description
The implementation of the ScaleRotateGestureHandler element.
Provides an API surface for platform-recognized pinch gesture events.
Receives MouseEvent::PinchGesture events via the normal mouse event
tree-walk and exposes cumulative scale, center position, and lifecycle callbacks.
Fields
enabled: Property<bool>active: Property<bool>scale: Property<f32>Cumulative scale factor relative to gesture start. Always 1.0 when the gesture starts, then updated as the gesture progresses (e.g., 2.0 means doubled, 0.5 means halved).
rotation: Property<f32>Cumulative rotation in degrees relative to gesture start. Always 0.0 when the gesture starts.
center: Property<LogicalPosition>started: Callback<VoidArg>updated: Callback<VoidArg>ended: Callback<VoidArg>cancelled: Callback<VoidArg>cached_rendering_data: CachedRenderingDataFIXME: remove this
Implementations
Sourceimpl ScaleRotateGestureHandler
impl ScaleRotateGestureHandler
Sourcepub const FIELD_OFFSETS: ScaleRotateGestureHandlerFieldsOffsets = ScaleRotateGestureHandlerFieldsOffsets
pub const FIELD_OFFSETS: ScaleRotateGestureHandlerFieldsOffsets = ScaleRotateGestureHandlerFieldsOffsets
Return a zero-sized helper whose methods return field offsets.