pub fn shared_string_replace_all(
s: &SharedString,
from: &str,
to: &str,
) -> SharedStringExpand description
Replaces all matches of from with to in s and returns the result as a new
SharedString.
pub fn shared_string_replace_all(
s: &SharedString,
from: &str,
to: &str,
) -> SharedStringReplaces all matches of from with to in s and returns the result as a new
SharedString.